/**
 *
 * $Id: $
 *
 */

#ifndef _GETOPT_H_
#define _GETOPT_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 * data structure to replace getopt globals
 */
typedef struct getopt_data_s {
    int opterr;
    int optind;
    int optopt;
    int optreset;
    char *optarg;
    const char *place;
} getopt_data_t;

/**
 * Initialize getopt data
 *
 * @param optdata   Pointer to a getopt_data_t structure
 */
void getopt_init(getopt_data_t* optdat);

/**
 * Initialize getopt data
 *
 * @param optdata   Pointer to a getopt_data_t structure
 * @param nargc     argc from main()
 * @param nargv     argv from main()
 * @param ostr      option selectors (see UNIX manpage)
 *
 * @return          option character encountered
 */
int getopt(getopt_data_t* optdat,
           int nargc, char * const nargv[], const char *ostr);

#ifndef HAVE_STRUCT_OPTION
struct option
{
    const char *name;
    int         has_arg;
    int        *flag;
    int         val;
};

#define no_argument 0
#define required_argument 1
#endif

int getopt_long(getopt_data_t* optdat,
            int argc, char *const argv[],
            const char *optstring,
            const struct option * longopts, int *longindex);

#ifdef __cplusplus
}
#endif

#endif /* _GETOPT_H_ */

/*
 * vim:ts=4:sw=4:tw=78:et
 */
